# pytoolsz-lnx

一组常用的Python工具，主要用于处理自己常用的工作问题，这个版本是针对linux的工作版本。
相比原有 [个人工具集](https://pypi.org/project/pytoolsz/) 要少很多工具，毕竟现在工作主力还是windows电脑。

目前仅有一个小工具包：

- utils ：一些常用的工具。

目前完成了部分便捷小工具。预测工具和更多绘图工具还在构建中。

现在已经可以直接使用pip安装了：

```bash
pip install pytoolsz-lnx
```
